package
Version:
v0.0.0-...-4e71f0c
Opens a new window with list of versions in this module.
Published: Jan 27, 2018
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 4
Opens a new window with list of known importers.
Documentation
¶
func Parallel(work func(), workers int)
func ParallelCheck(work func() error, workers int, errors chan<- error)
func ParallelLog(work func() error, workers int)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.